@@ -224,13 +224,13 @@ func (self *FilesController) GetMouseKeybindings(opts types.KeybindingsOpts) []*
 	}
 }
 
-func (self *FilesController) GetOnRenderToMain() func() error {
-	return func() error {
-		return self.c.Helpers().Diff.WithDiffModeCheck(func() error {
+func (self *FilesController) GetOnRenderToMain() func() {
+	return func() {
+		self.c.Helpers().Diff.WithDiffModeCheck(func() {
 			node := self.context().GetSelected()
 
 			if node == nil {
-				return self.c.RenderToMainViews(types.RefreshMainOpts{
+				self.c.RenderToMainViews(types.RefreshMainOpts{
 					Pair: self.c.MainViewPairs().Normal,
 					Main: &types.ViewUpdateOpts{
 						Title:    self.c.Tr.DiffTitle,
@@ -238,16 +238,18 @@ func (self *FilesController) GetOnRenderToMain() func() error {
 						Task:     types.NewRenderStringTask(self.c.Tr.NoChangedFiles),
 					},
 				})
+				return
 			}
 
 			if node.File != nil && node.File.HasInlineMergeConflicts {
 				hasConflicts, err := self.c.Helpers().MergeConflicts.SetMergeState(node.GetPath())
 				if err != nil {
-					return err
+					return
 				}
 
 				if hasConflicts {
-					return self.c.Helpers().MergeConflicts.Render()
+					self.c.Helpers().MergeConflicts.Render()
+					return
 				}
 			}
 
@@ -258,7 +260,7 @@ func (self *FilesController) GetOnRenderToMain() func() error {
 				pair = self.c.MainViewPairs().Staging
 			}
 
-			split := self.c.UserConfig.Gui.SplitDiff == "always" || (node.GetHasUnstagedChanges() && node.GetHasStagedChanges())
+			split := self.c.UserConfig().Gui.SplitDiff == "always" || (node.GetHasUnstagedChanges() && node.GetHasStagedChanges())
 			mainShowsStaged := !split && node.GetHasStagedChanges()
 
 			cmdObj := self.c.Git().WorkingTree.WorktreeFileDiffCmdObj(node, false, mainShowsStaged)
@@ -290,7 +292,7 @@ func (self *FilesController) GetOnRenderToMain() func() error {
 				}
 			}
 
-			return self.c.RenderToMainViews(refreshOpts)
+			self.c.RenderToMainViews(refreshOpts)
 		})
 	}
 }
@@ -401,16 +403,18 @@ func (self *FilesController) pressWithLock(selectedNodes []*filetree.FileNode) e
 
 	selectedNodes = normalisedSelectedNodes(selectedNodes)
 
-	// If any node has unstaged changes, we'll stage all the selected nodes. Otherwise,
-	// we unstage all the selected nodes.
-	if someNodesHaveUnstagedChanges(selectedNodes) {
+	// If any node has unstaged changes, we'll stage all the selected unstaged nodes (staging already staged deleted files/folders would fail).
+	// Otherwise, we unstage all the selected nodes.
+	unstagedSelectedNodes := filterNodesHaveUnstagedChanges(selectedNodes)
+
+	if len(unstagedSelectedNodes) > 0 {
 		self.c.LogAction(self.c.Tr.Actions.StageFile)
 
-		if err := self.optimisticChange(selectedNodes, self.optimisticStage); err != nil {
+		if err := self.optimisticChange(unstagedSelectedNodes, self.optimisticStage); err != nil {
 			return err
 		}
 
-		if err := self.c.Git().WorkingTree.StageFiles(toPaths(selectedNodes)); err != nil {
+		if err := self.c.Git().WorkingTree.StageFiles(toPaths(unstagedSelectedNodes)); err != nil {
 			return err
 		}
 	} else {
@@ -452,7 +456,8 @@ func (self *FilesController) press(nodes []*filetree.FileNode) error {
 		return err
 	}
 
-	return self.context().HandleFocus(types.OnFocusOpts{})
+	self.context().HandleFocus(types.OnFocusOpts{})
+	return nil
 }
 
 func (self *FilesController) Context() types.Context {
@@ -500,7 +505,8 @@ func (self *FilesController) EnterFile(opts types.OnFocusOpts) error {
 		return errors.New(self.c.Tr.FileStagingRequirements)
 	}
 
-	return self.c.PushContext(self.c.Contexts().Staging, opts)
+	self.c.Context().Push(self.c.Contexts().Staging, opts)
+	return nil
 }
 
 func (self *FilesController) toggleStagedAll() error {
@@ -512,7 +518,8 @@ func (self *FilesController) toggleStagedAll() error {
 		return err
 	}
 
-	return self.context().HandleFocus(types.OnFocusOpts{})
+	self.context().HandleFocus(types.OnFocusOpts{})
+	return nil
 }
 
 func (self *FilesController) toggleStagedAllWithLock() error {
@@ -594,13 +601,15 @@ func (self *FilesController) ignoreOrExcludeUntracked(node *filetree.FileNode, t
 
 func (self *FilesController) ignoreOrExcludeFile(node *filetree.FileNode, trText string, trPrompt string, trAction string, f func(string) error) error {
 	if node.GetIsTracked() {
-		return self.c.Confirm(types.ConfirmOpts{
+		self.c.Confirm(types.ConfirmOpts{
 			Title:  trText,
 			Prompt: trPrompt,
 			HandleConfirm: func() error {
 				return self.ignoreOrExcludeTracked(node, trAction, f)
 			},
 		})
+
+		return nil
 	}
 	return self.ignoreOrExcludeUntracked(node, trAction, f)
 }
@@ -653,7 +662,7 @@ func (self *FilesController) refresh() error {
 }
 
 func (self *FilesController) handleAmendCommitPress() error {
-	return self.c.Confirm(types.ConfirmOpts{
+	self.c.Confirm(types.ConfirmOpts{
 		Title:  self.c.Tr.AmendLastCommitTitle,
 		Prompt: self.c.Tr.SureToAmend,
 		HandleConfirm: func() error {
@@ -666,6 +675,8 @@ func (self *FilesController) handleAmendCommitPress() error {
 			})
 		},
 	})
+
+	return nil
 }
 
 func (self *FilesController) handleStatusFilterPressed() error {
@@ -952,7 +963,7 @@ func (self *FilesController) toggleTreeView() error {
 }
 
 func (self *FilesController) handleStashSave(stashFunc func(message string) error, action string) error {
-	return self.c.Prompt(types.PromptOpts{
+	self.c.Prompt(types.PromptOpts{
 		Title: self.c.Tr.StashChanges,
 		HandleConfirm: func(stashComment string) error {
 			self.c.LogAction(action)
@@ -963,6 +974,8 @@ func (self *FilesController) handleStashSave(stashFunc func(message string) erro
 			return self.c.Refresh(types.RefreshOptions{Scope: []types.RefreshableView{types.STASH, types.FILES}})
 		},
 	})
+
+	return nil
 }
 
 func (self *FilesController) onClickMain(opts gocui.ViewMouseBindingOpts) error {
@@ -1009,10 +1022,14 @@ func normalisedSelectedNodes(selectedNodes []*filetree.FileNode) []*filetree.Fil
 
 func isDescendentOfSelectedNodes(node *filetree.FileNode, selectedNodes []*filetree.FileNode) bool {
 	for _, selectedNode := range selectedNodes {
+		if selectedNode.IsFile() {
+			continue
+		}
+
 		selectedNodePath := selectedNode.GetPath()
 		nodePath := node.GetPath()
 
-		if strings.HasPrefix(nodePath, selectedNodePath) && nodePath != selectedNodePath {
+		if strings.HasPrefix(nodePath, selectedNodePath+"/") {
 			return true
 		}
 	}
@@ -1027,6 +1044,12 @@ func someNodesHaveStagedChanges(nodes []*filetree.FileNode) bool {
 	return lo.SomeBy(nodes, (*filetree.FileNode).GetHasStagedChanges)
 }
 
+func filterNodesHaveUnstagedChanges(nodes []*filetree.FileNode) []*filetree.FileNode {
+	return lo.Filter(nodes, func(node *filetree.FileNode, _ int) bool {
+		return node.GetHasUnstagedChanges()
+	})
+}
+
 func (self *FilesController) canRemove(selectedNodes []*filetree.FileNode) *types.DisabledReason {
 	submodules := self.c.Model().Submodules
 	submoduleCount := lo.CountBy(selectedNodes, func(node *filetree.FileNode) bool {
@@ -1062,60 +1085,65 @@ func (self *FilesController) remove(selectedNodes []*filetree.FileNode) error {
 
 	selectedNodes = normalisedSelectedNodes(selectedNodes)
 
-	menuItems := []*types.MenuItem{
-		{
-			Label: self.c.Tr.DiscardAllChanges,
-			OnPress: func() error {
-				self.c.LogAction(self.c.Tr.Actions.DiscardAllChangesInFile)
+	discardAllChangesItem := types.MenuItem{
+		Label: self.c.Tr.DiscardAllChanges,
+		OnPress: func() error {
+			self.c.LogAction(self.c.Tr.Actions.DiscardAllChangesInFile)
 
-				if self.context().IsSelectingRange() {
-					defer self.context().CancelRangeSelect()
+			if self.context().IsSelectingRange() {
+				defer self.context().CancelRangeSelect()
+			}
+
+			for _, node := range selectedNodes {
+				if err := self.c.Git().WorkingTree.DiscardAllDirChanges(node); err != nil {
+					return err
 				}
+			}
 
-				for _, node := range selectedNodes {
-					if err := self.c.Git().WorkingTree.DiscardAllDirChanges(node); err != nil {
-						return err
-					}
-				}
-
-				return self.c.Refresh(types.RefreshOptions{Mode: types.ASYNC, Scope: []types.RefreshableView{types.FILES, types.WORKTREES}})
-			},
-			Key: self.c.KeybindingsOpts().GetKey(self.c.UserConfig.Keybinding.Files.ConfirmDiscard),
-			Tooltip: utils.ResolvePlaceholderString(
-				self.c.Tr.DiscardAllTooltip,
-				map[string]string{
-					"path": self.formattedPaths(selectedNodes),
-				},
-			),
+			return self.c.Refresh(types.RefreshOptions{Mode: types.ASYNC, Scope: []types.RefreshableView{types.FILES, types.WORKTREES}})
 		},
+		Key: self.c.KeybindingsOpts().GetKey(self.c.UserConfig().Keybinding.Files.ConfirmDiscard),
+		Tooltip: utils.ResolvePlaceholderString(
+			self.c.Tr.DiscardAllTooltip,
+			map[string]string{
+				"path": self.formattedPaths(selectedNodes),
+			},
+		),
 	}
 
-	if someNodesHaveStagedChanges(selectedNodes) && someNodesHaveUnstagedChanges(selectedNodes) {
-		menuItems = append(menuItems, &types.MenuItem{
-			Label: self.c.Tr.DiscardUnstagedChanges,
-			OnPress: func() error {
-				self.c.LogAction(self.c.Tr.Actions.DiscardAllUnstagedChangesInFile)
+	discardUnstagedChangesItem := types.MenuItem{
+		Label: self.c.Tr.DiscardUnstagedChanges,
+		OnPress: func() error {
+			self.c.LogAction(self.c.Tr.Actions.DiscardAllUnstagedChangesInFile)
 
-				if self.context().IsSelectingRange() {
-					defer self.context().CancelRangeSelect()
+			if self.context().IsSelectingRange() {
+				defer self.context().CancelRangeSelect()
+			}
+
+			for _, node := range selectedNodes {
+				if err := self.c.Git().WorkingTree.DiscardUnstagedDirChanges(node); err != nil {
+					return err
 				}
+			}
 
-				for _, node := range selectedNodes {
-					if err := self.c.Git().WorkingTree.DiscardUnstagedDirChanges(node); err != nil {
-						return err
-					}
-				}
-
-				return self.c.Refresh(types.RefreshOptions{Mode: types.ASYNC, Scope: []types.RefreshableView{types.FILES, types.WORKTREES}})
+			return self.c.Refresh(types.RefreshOptions{Mode: types.ASYNC, Scope: []types.RefreshableView{types.FILES, types.WORKTREES}})
+		},
+		Key: 'u',
+		Tooltip: utils.ResolvePlaceholderString(
+			self.c.Tr.DiscardUnstagedTooltip,
+			map[string]string{
+				"path": self.formattedPaths(selectedNodes),
 			},
-			Key: 'u',
-			Tooltip: utils.ResolvePlaceholderString(
-				self.c.Tr.DiscardUnstagedTooltip,
-				map[string]string{
-					"path": self.formattedPaths(selectedNodes),
-				},
-			),
-		})
+		),
+	}
+
+	if !someNodesHaveStagedChanges(selectedNodes) || !someNodesHaveUnstagedChanges(selectedNodes) {
+		discardUnstagedChangesItem.DisabledReason = &types.DisabledReason{Text: self.c.Tr.DiscardUnstagedDisabled}
+	}
+
+	menuItems := []*types.MenuItem{
+		&discardAllChangesItem,
+		&discardUnstagedChangesItem,
 	}
 
 	return self.c.Menu(types.CreateMenuOptions{Title: self.c.Tr.DiscardChangesTitle, Items: menuItems})
