@@ -1,6 +1,8 @@
 package helpers
 
 import (
+	"strings"
+
 	"github.com/jesseduffield/gocui"
 	"github.com/jesseduffield/lazygit/pkg/gui/types"
 	"github.com/jesseduffield/lazygit/pkg/utils"
@@ -30,7 +32,7 @@ func (self *BranchesHelper) ConfirmDeleteRemote(remoteName string, branchName st
 			"upstream":           remoteName,
 		},
 	)
-	return self.c.Confirm(types.ConfirmOpts{
+	self.c.Confirm(types.ConfirmOpts{
 		Title:  title,
 		Prompt: prompt,
 		HandleConfirm: func() error {
@@ -43,4 +45,10 @@ func (self *BranchesHelper) ConfirmDeleteRemote(remoteName string, branchName st
 			})
 		},
 	})
+
+	return nil
+}
+
+func ShortBranchName(fullBranchName string) string {
+	return strings.TrimPrefix(strings.TrimPrefix(fullBranchName, "refs/heads/"), "refs/remotes/")
 }
