@@ -1,9 +1,13 @@
 package helpers
 
 import (
+	"strings"
+
 	"github.com/jesseduffield/lazygit/pkg/commands/git_commands"
+	"github.com/jesseduffield/lazygit/pkg/commands/models"
 	"github.com/jesseduffield/lazygit/pkg/gui/context"
 	"github.com/jesseduffield/lazygit/pkg/gui/modes/diffing"
+	"github.com/jesseduffield/lazygit/pkg/gui/style"
 	"github.com/jesseduffield/lazygit/pkg/gui/types"
 	"github.com/samber/lo"
 )
@@ -19,7 +23,7 @@ func NewDiffHelper(c *HelperCommon) *DiffHelper {
 }
 
 func (self *DiffHelper) DiffArgs() []string {
-	output := []string{self.c.Modes().Diffing.Ref}
+	output := []string{"--stat", "-p", self.c.Modes().Diffing.Ref}
 
 	right := self.currentDiffTerminal()
 	if right != "" {
@@ -46,16 +50,48 @@ func (self *DiffHelper) DiffArgs() []string {
 	return output
 }
 
+// Returns an update task that can be passed to RenderToMainViews to render a
+// diff for the selected commit(s). We need to pass both the selected commit
+// and the refRange for a range selection. If the refRange is nil (meaning that
+// either there's no range, or it can't be diffed for some reason), then we want
+// to fall back to rendering the diff for the single commit.
+func (self *DiffHelper) GetUpdateTaskForRenderingCommitsDiff(commit *models.Commit, refRange *types.RefRange) types.UpdateTask {
+	if refRange != nil {
+		from, to := refRange.From, refRange.To
+		args := []string{from.ParentRefName(), to.RefName(), "--stat", "-p"}
+		if self.c.GetAppState().IgnoreWhitespaceInDiffView {
+			args = append(args, "--ignore-all-space")
+		}
+		args = append(args, "--")
+		if path := self.c.Modes().Filtering.GetPath(); path != "" {
+			args = append(args, path)
+		}
+		cmdObj := self.c.Git().Diff.DiffCmdObj(args)
+		task := types.NewRunPtyTask(cmdObj.GetCmd())
+		task.Prefix = style.FgYellow.Sprintf("%s %s-%s\n\n", self.c.Tr.ShowingDiffForRange, from.ShortRefName(), to.ShortRefName())
+		return task
+	}
+
+	cmdObj := self.c.Git().Commit.ShowCmdObj(commit.Hash, self.c.Modes().Filtering.GetPath())
+	return types.NewRunPtyTask(cmdObj.GetCmd())
+}
+
 func (self *DiffHelper) ExitDiffMode() error {
 	self.c.Modes().Diffing = diffing.New()
 	return self.c.Refresh(types.RefreshOptions{Mode: types.ASYNC})
 }
 
-func (self *DiffHelper) RenderDiff() error {
-	cmdObj := self.c.Git().Diff.DiffCmdObj(self.DiffArgs())
+func (self *DiffHelper) RenderDiff() {
+	args := self.DiffArgs()
+	cmdObj := self.c.Git().Diff.DiffCmdObj(args)
 	task := types.NewRunPtyTask(cmdObj.GetCmd())
+	task.Prefix = style.FgMagenta.Sprintf(
+		"%s %s\n\n",
+		self.c.Tr.ShowingGitDiff,
+		"git diff "+strings.Join(args, " "),
+	)
 
-	return self.c.RenderToMainViews(types.RefreshMainOpts{
+	self.c.RenderToMainViews(types.RefreshMainOpts{
 		Pair: self.c.MainViewPairs().Normal,
 		Main: &types.ViewUpdateOpts{
 			Title:    "Diff",
@@ -70,7 +106,7 @@ func (self *DiffHelper) RenderDiff() error {
 // which becomes an option when you bring up the diff menu, but when you're just
 // flicking through branches it will be using the local branch name.
 func (self *DiffHelper) CurrentDiffTerminals() []string {
-	c := self.c.CurrentSideContext()
+	c := self.c.Context().CurrentSide()
 
 	if c.GetKey() == "" {
 		return nil
@@ -93,7 +129,7 @@ func (self *DiffHelper) currentDiffTerminal() string {
 }
 
 func (self *DiffHelper) currentlySelectedFilename() string {
-	currentContext := self.c.CurrentContext()
+	currentContext := self.c.Context().Current()
 
 	switch currentContext := currentContext.(type) {
 	case types.IListContext:
@@ -105,12 +141,12 @@ func (self *DiffHelper) currentlySelectedFilename() string {
 	return ""
 }
 
-func (self *DiffHelper) WithDiffModeCheck(f func() error) error {
+func (self *DiffHelper) WithDiffModeCheck(f func()) {
 	if self.c.Modes().Diffing.Active() {
-		return self.RenderDiff()
+		self.RenderDiff()
+	} else {
+		f()
 	}
-
-	return f()
 }
 
 func (self *DiffHelper) IgnoringWhitespaceSubTitle() string {
