@@ -87,10 +87,10 @@ func (self *WindowArrangementHelper) GetWindowDimensions(informationStr string,
 	args := WindowArrangementArgs{
 		Width:               width,
 		Height:              height,
-		UserConfig:          self.c.UserConfig,
+		UserConfig:          self.c.UserConfig(),
 		CurrentWindow:       self.windowHelper.CurrentWindow(),
-		CurrentSideWindow:   self.c.CurrentSideContext().GetWindowName(),
-		CurrentStaticWindow: self.c.CurrentStaticContext().GetWindowName(),
+		CurrentSideWindow:   self.c.Context().CurrentSide().GetWindowName(),
+		CurrentStaticWindow: self.c.Context().CurrentStatic().GetWindowName(),
 		SplitMainPanel:      repoState.GetSplitMainPanel(),
 		ScreenMode:          repoState.GetScreenMode(),
 		AppStatus:           appStatus,
