@@ -74,9 +74,9 @@ func (self *StashController) GetKeybindings(opts types.KeybindingsOpts) []*types
 	return bindings
 }
 
-func (self *StashController) GetOnRenderToMain() func() error {
-	return func() error {
-		return self.c.Helpers().Diff.WithDiffModeCheck(func() error {
+func (self *StashController) GetOnRenderToMain() func() {
+	return func() {
+		self.c.Helpers().Diff.WithDiffModeCheck(func() {
 			var task types.UpdateTask
 			stashEntry := self.context().GetSelected()
 			if stashEntry == nil {
@@ -87,7 +87,7 @@ func (self *StashController) GetOnRenderToMain() func() error {
 				)
 			}
 
-			return self.c.RenderToMainViews(types.RefreshMainOpts{
+			self.c.RenderToMainViews(types.RefreshMainOpts{
 				Pair: self.c.MainViewPairs().Normal,
 				Main: &types.ViewUpdateOpts{
 					Title:    "Stash",
@@ -111,20 +111,23 @@ func (self *StashController) handleStashApply(stashEntry *models.StashEntry) err
 		if err != nil {
 			return err
 		}
+		self.c.Context().Push(self.c.Contexts().Files)
 		return nil
 	}
 
-	if self.c.UserConfig.Gui.SkipStashWarning {
+	if self.c.UserConfig().Gui.SkipStashWarning {
 		return apply()
 	}
 
-	return self.c.Confirm(types.ConfirmOpts{
+	self.c.Confirm(types.ConfirmOpts{
 		Title:  self.c.Tr.StashApply,
 		Prompt: self.c.Tr.SureApplyStashEntry,
 		HandleConfirm: func() error {
 			return apply()
 		},
 	})
+
+	return nil
 }
 
 func (self *StashController) handleStashPop(stashEntry *models.StashEntry) error {
@@ -135,24 +138,27 @@ func (self *StashController) handleStashPop(stashEntry *models.StashEntry) error
 		if err != nil {
 			return err
 		}
+		self.c.Context().Push(self.c.Contexts().Files)
 		return nil
 	}
 
-	if self.c.UserConfig.Gui.SkipStashWarning {
+	if self.c.UserConfig().Gui.SkipStashWarning {
 		return pop()
 	}
 
-	return self.c.Confirm(types.ConfirmOpts{
+	self.c.Confirm(types.ConfirmOpts{
 		Title:  self.c.Tr.StashPop,
 		Prompt: self.c.Tr.SurePopStashEntry,
 		HandleConfirm: func() error {
 			return pop()
 		},
 	})
+
+	return nil
 }
 
 func (self *StashController) handleStashDrop(stashEntry *models.StashEntry) error {
-	return self.c.Confirm(types.ConfirmOpts{
+	self.c.Confirm(types.ConfirmOpts{
 		Title:  self.c.Tr.StashDrop,
 		Prompt: self.c.Tr.SureDropStashEntry,
 		HandleConfirm: func() error {
@@ -165,6 +171,8 @@ func (self *StashController) handleStashDrop(stashEntry *models.StashEntry) erro
 			return nil
 		},
 	})
+
+	return nil
 }
 
 func (self *StashController) postStashRefresh() error {
@@ -183,7 +191,7 @@ func (self *StashController) handleRenameStashEntry(stashEntry *models.StashEntr
 		},
 	)
 
-	return self.c.Prompt(types.PromptOpts{
+	self.c.Prompt(types.PromptOpts{
 		Title:          message,
 		InitialContent: stashEntry.Name,
 		HandleConfirm: func(response string) error {
@@ -198,4 +206,6 @@ func (self *StashController) handleRenameStashEntry(stashEntry *models.StashEntr
 			return nil
 		},
 	})
+
+	return nil
 }
