@@ -7,7 +7,7 @@ import (
 
 var AmendNonHeadCommitDuringRebase = NewIntegrationTest(NewIntegrationTestArgs{
 	Description:  "Tries to amend a commit that is not the head while already rebasing, resulting in an error message",
-	ExtraCmdArgs: "",
+	ExtraCmdArgs: []string{},
 	Skip:         false,
 	SetupConfig:  func(config *config.AppConfig) {},
 	SetupRepo: func(shell *Shell) {
@@ -34,10 +34,7 @@ var AmendNonHeadCommitDuringRebase = NewIntegrationTest(NewIntegrationTestArgs{
 				NavigateToLine(Contains(commit)).
 				Press(keys.Commits.AmendToCommit)
 
-			t.ExpectPopup().Alert().
-				Title(Equals("Error")).
-				Content(Contains("Can't perform this action during a rebase")).
-				Confirm()
+			t.ExpectToast(Contains("Can't perform this action during a rebase"))
 		}
 	},
 })
